==> unicore-nagios-plugins_2.1.0.orig.tar.gz: test/umi2commons.pl <==
use FindBin '$Bin';
use Test::More tests => 44;
use Cwd;
use warnings;
use strict;

require "$Bin/../umi2/commons.pm";
$commons::config{'testmode'} = 1;
$ENV{LANG} = 'C';
`rm -rf /tmp/umi2commons`;

is(commons::get_plugin_name(), 'umi2commons', 'get_plugin_name()');

$commons::config{'LOGS_DIR'} = '/tmp';
is(commons::get_wd(), '/tmp/umi2commons/', 'get_wd()');

chdir('/');
rmdir('/tmp/umi2commons');
commons::setup_environment();
is(getcwd(), '/tmp/umi2commons', 'setup_environment() - cwd changed');
ok(-d '/tmp/umi2commons', 'setup_environment() - logs directory was created');

sub get_output {
  my $command = shift;
  my $result = do {
    our $msg;
    open local( *STDOUT), '>', \$msg or die $!;
    eval $command;
    $msg
  };
  return $result ? $result : undef;
}

$commons::config{'version'} = '1.0';
is(get_output('commons::show_version();'), "UNICORE Monitoring Infrastructure: umi2commons, version 1.0\nExit code: 0\n", 'show_version()');

is(get_output('commons::check_file_existence("/tmp/umi2commons/wrong");'), "UNKNOWN: Missing required file: /tmp/umi2commons/wrong!\nExit code: 3\n", 'check_file_existence() - file missing');
`touch /tmp/umi2commons/okfile`;
is(get_output('commons::check_file_existence("/tmp/umi2commons/okfile");'), undef, 'check_file_existence() - file found');
`rm /tmp/umi2commons/okfile`;

is($commons::verbosity, 1, 'verbosity level is 1 at default');
is(get_output('commons::message("test");'), "test\n", 'message() - verbosity 1, level 1');
is(get_output('commons::message("test", 2);'), undef, 'message() - verbosity 1, level 2');

is(get_output('commons::exit_plugin("OK: Test", "`echo Line`");'), "OK: Test\nLine\nExit code: 0\n", 'exit_plugin() - multiline output at verbosity 1');
$commons::verbosity = 0;
is(get_output('commons::exit_plugin("OK: Test", "`echo Line`");'), "OK: Test\nExit code: 0\n", 'exit_plugin() - multiline output at verbosity 0');
$commons::verbosity = 1;

is(get_output('commons::exit_plugin("WARNING: Test");'), "WARNING: Test\nExit code: 1\n", 'exit_plugin() - exit code at warning state');
is(get_output('commons::exit_plugin("CRITICAL: Test");'), "CRITICAL: Test\nExit code: 2\n", 'exit_plugin() - exit code at critical state');
is(get_output('commons::exit_plugin("UNKNOWN: Test");'), "UNKNOWN: Test\nExit code: 3\n", 'exit_plugin() - exit code at unknown state');
is(get_output('commons::exit_plugin("WRONG: Test");'), "Wrong plugin output line: WRONG: Test\nExit code: 3\n", 'exit_plugin() - exit code at wrong state');

$commons::verbosity = 2;
is(get_output('commons::exit_plugin("CRITICAL: Test");'), "Listing checker output:\n-----------------------\nCRITICAL: Test\n-----------------------\nExit code: 2\n", 'exit_plugin() - verbose mode without debug trace');
is(get_output('commons::exit_plugin("CRITICAL: Test", "`echo test2`");'), "Listing checker output:\n-----------------------\nCRITICAL: Test\ntest2\n-----------------------\nExit code: 2\n", 'exit_plugin() - verbose mode with debug trace');

@commons::tempfiles = ();
is(get_output('commons::create_temp_file("ttt");'), "Created temp file: /tmp/umi2commons/ttt\n", 'create_temp_file() - success message');
is($commons::tempfiles[0], '/tmp/umi2commons/ttt', 'create_temp_file() - temp file added to queue');
$commons::verbosity = 1;
is(get_output('commons::create_temp_file("ttt");'), "UNKNOWN: temporary file /tmp/umi2commons/ttt already exists\nExit code: 3\n", 'create_temp_file() - file already exists');
is(get_output('commons::create_temp_file("unknown_dir/ttt");'), "UNKNOWN: Unable to create temporary file: touch: cannot touch `/tmp/umi2commons/unknown_dir/ttt': No such file or directory\nExit code: 3\n", 'create_temp_file() - unable to create file');

$commons::verbosity = 2;
is(get_output('commons::clear_temp()'), "Temporary file deleted: /tmp/umi2commons/ttt\n", 'clear temp() - temp file deletion');
ok(!-e '/tmp/umi2commons/ttt', 'clear_temp() - file really deleted');
get_output("commons::create_temp_file('ttt')");
$commons::verbosity = 3;
is(get_output('commons::clear_temp()'), "Temporary file NOT DELETED: /tmp/umi2commons/ttt\n", 'clear temp() - avoiding temp file deletion');
ok(-e '/tmp/umi2commons/ttt', 'clear_temp() - file not deleted in third verbosity mode');
$commons::verbosity = 1;

is(get_output('commons::check_config("LOGS_DIR")'), undef, 'check_config() - real option');
is(get_output('commons::check_config("LOGS_DIR, TIMEOUT")'), "UNKNOWN: Configuration option TIMEOUT is missing!\nExit code: 3\n", 'check_config() - non existent option');
ok(commons::check_config("LOGS_DIR, TIMEOUT", 1) eq 1, "check_config() - non existent option, light version");

ok(commons::is_debug_enabled() eq '', 'is_debug_enabled() - no');
$commons::verbosity = 3;
ok(commons::is_debug_enabled() eq 1, 'is_debug_enabled() - yes');
$commons::verbosity = 1;

$commons::config{'readme_location'} = '/tmp/umi2commons/helpmessage';
`echo -n "Plugin name\n\nHelp message\n.Description" > $commons::config{'readme_location'}`;
is(get_output('commons::show_help();'), "Help message\nExit code: 0\n", 'show_help() - file exists');
$commons::config{'readme_location'} = '/tmp/umi2commons/helpmessage2';
is(get_output('commons::show_help();'), "UNKNOWN: Couldn't load readme file /tmp/umi2commons/helpmessage2!\nExit code: 3\n", 'show_help() - file does not exist');

#$commons::verbosity = 2;
our @conditions = ({'test' => '2 + 2 eq 4', 'output' => 'OK: All right', 'show_debug' => 0 });
is(get_output('commons::check_conditions(\@main::conditions)'), "OK: All right\nExit code: 0\n", 'check_conditions() - one true condition without debug');
@conditions = ({'test' => '2 + 2 eq 4', 'output' => 'OK: All right', 'show_debug' => '`echo Additional debug`' });
is(get_output('commons::check_conditions(\@main::conditions)'), "OK: All right\nAdditional debug\nExit code: 0\n", 'check_conditions() - one true condition with debug');
$commons::verbosity = 2;
@conditions = ( {'test' => '2 + 2 eq 5', 'output' => 'CRITICAL: Wrong', 'show_debug' => 0 }, {'test' => '2 + 2 eq 4', 'output' => 'OK: All right', 'show_debug' => 0 });
is(get_output('commons::check_conditions(\@main::conditions)'), "Checking 2 + 2 eq 5...\nChecking 2 + 2 eq 4...\nListing checker output:\n-----------------------\nOK: All right\n-----------------------\nExit code: 0\n", 'check_conditions() - false and true condition in debug mode');
$commons::verbosity = 1;
@conditions = ({'test' => '2 + 2 eq 5', 'output' => 'CRITICAL: Wrong!', 'show_debug' => 0 });
is(get_output('commons::check_conditions(\@main::conditions)'), undef, 'check_conditions() - only false condition(s)');
@conditions = ({'test' => '2 + 2 eq 4', 'output' => 'CRITICAL: Wrong!', 'show_debug' => 0 });
is(get_output('commons::check_conditions(\@main::conditions)'), "CRITICAL: Wrong!\nExit code: 2\n", 'check_conditions() - non-ok exit status ');

$commons::config{'config_location'} = '/tmp/umi2commons/myGrid/mySite1/myHost1/check_workflow.config';
$commons::config{'UCC_CONFIG'} = '/tmp/umi2commons/myGrid/ucc.config';
$commons::config{'LOGS_DIR'} = '/tmp/umi2commons';
is(get_output('commons::locate_log4j(\'ucc\')'), "UNKNOWN: Unable to find log4j properties file in any place: /tmp/umi2commons/myGrid/mySite1/myHost1/log4j-ucc.properties, /tmp/umi2commons/myGrid/log4j-ucc.properties, /tmp/umi2commons/log4j-ucc.properties\nExit code: 3\n", 'locate_log4j() - missing configuration');
`touch /tmp/umi2commons/log4j-ucc.properties`;
is(commons::locate_log4j('ucc'), '/tmp/umi2commons/log4j-ucc.properties', 'locate_log4j() - logs directory');
`mkdir -p /tmp/umi2commons/myGrid/mySite1/myHost1/`;
`touch /tmp/umi2commons/myGrid/log4j-ucc.properties`;
is(commons::locate_log4j('ucc'), '/tmp/umi2commons/myGrid/log4j-ucc.properties', 'locate_log4j() - client config directory');
`touch /tmp/umi2commons/myGrid/mySite1/myHost1/log4j-ucc.properties`;
is(commons::locate_log4j('ucc'), '/tmp/umi2commons/myGrid/mySite1/myHost1/log4j-ucc.properties', 'locate_log4j() - probe config directory');
$commons::verbosity = 2;
is(get_output('commons::locate_log4j(\'uvosclc\')'), "Listing checker output:\n-----------------------\nUNKNOWN: Unable to find log4j properties file in any place: /tmp/umi2commons/myGrid/mySite1/myHost1/log4j-uvosclc-debug.properties, /tmp/umi2commons/myGrid/log4j-uvosclc-debug.properties, /tmp/umi2commons/log4j-uvosclc-debug.properties\n-----------------------\nExit code: 3\n", 'locate_log4j() - missing debug');
`touch /tmp/umi2commons/myGrid/mySite1/myHost1/log4j-uvosclc-debug.properties`;
is(commons::locate_log4j('uvosclc'), '/tmp/umi2commons/myGrid/mySite1/myHost1/log4j-uvosclc-debug.properties', 'locate_log4j() - debug file');



`rm -rf /tmp/umi2commons`;

==> unicore-nagios-plugins_2.3.2.orig.tar.gz: test/umi2commons.pl <==
use FindBin '$Bin';
use Test::More tests => 43;
use Cwd;
use warnings;
use strict;

require "$Bin/../umi2/commons.pm";
$commons::config{'testmode'} = 1;
$ENV{LANG} = 'C';
`rm -rf /tmp/umi2commons`;

is(commons::get_plugin_name(), 'umi2commons', 'get_plugin_name()');

$commons::config{'LOGS_DIR'} = '/tmp';
is(commons::get_wd(), '/tmp/umi2commons/', 'get_wd()');

chdir('/');
rmdir('/tmp/umi2commons');
commons::setup_environment();
is(getcwd(), '/tmp/umi2commons', 'setup_environment() - cwd changed');
ok(-d '/tmp/umi2commons', 'setup_environment() - logs directory was created');

sub get_output {
  my $command = shift;
  my $result = do {
    our $msg;
    open local( *STDOUT), '>', \$msg or die $!;
    eval $command;
    $msg
  };
  return $result ? $result : undef;
}

$commons::config{'version'} = '1.0';
is(get_output('commons::show_version();'), "UNICORE Monitoring Infrastructure: umi2commons, version 1.0\nExit code: 0\n", 'show_version()');

is(get_output('commons::check_file_existence("/tmp/umi2commons/wrong");'), "UNKNOWN: Missing required file: /tmp/umi2commons/wrong!\nExit code: 3\n", 'check_file_existence() - file missing');
`touch /tmp/umi2commons/okfile`;
is(get_output('commons::check_file_existence("/tmp/umi2commons/okfile");'), undef, 'check_file_existence() - file found');
`rm /tmp/umi2commons/okfile`;

is($commons::verbosity, 1, 'verbosity level is 1 at default');
is(get_output('commons::message("test");'), "test\n", 'message() - verbosity 1, level 1');
is(get_output('commons::message("test", 2);'), undef, 'message() - verbosity 1, level 2');

is(get_output('commons::exit_plugin("OK: Test", "`echo Line`");'), "OK: Test\nLine\nExit code: 0\n", 'exit_plugin() - multiline output at verbosity 1');
$commons::verbosity = 0;
is(get_output('commons::exit_plugin("OK: Test", "`echo Line`");'), "OK: Test\nExit code: 0\n", 'exit_plugin() - multiline output at verbosity 0');
$commons::verbosity = 1;

is(get_output('commons::exit_plugin("WARNING: Test");'), "WARNING: Test\nExit code: 1\n", 'exit_plugin() - exit code at warning state');
is(get_output('commons::exit_plugin("CRITICAL: Test");'), "CRITICAL: Test\nExit code: 2\n", 'exit_plugin() - exit code at critical state');
is(get_output('commons::exit_plugin("UNKNOWN: Test");'), "UNKNOWN: Test\nExit code: 3\n", 'exit_plugin() - exit code at unknown state');
is(get_output('commons::exit_plugin("WRONG: Test");'), "Wrong plugin output line: WRONG: Test\nExit code: 3\n", 'exit_plugin() - exit code at wrong state');

$commons::verbosity = 2;
is(get_output('commons::exit_plugin("CRITICAL: Test");'), "Listing checker output:\n-----------------------\nCRITICAL: Test\n-----------------------\nExit code: 2\n", 'exit_plugin() - verbose mode without debug trace');
is(get_output('commons::exit_plugin("CRITICAL: Test", "`echo test2`");'), "Listing checker output:\n-----------------------\nCRITICAL: Test\ntest2\n-----------------------\nExit code: 2\n", 'exit_plugin() - verbose mode with debug trace');

@commons::tempfiles = ();
is(get_output('commons::create_temp_file("ttt");'), "Created temp file: /tmp/umi2commons/ttt\n", 'create_temp_file() - success message');
is($commons::tempfiles[0], '/tmp/umi2commons/ttt', 'create_temp_file() - temp file added to queue');
$commons::verbosity = 1;
ok(get_output('commons::create_temp_file("unknown_dir/ttt");') =~ "UNKNOWN: Unable to create temporary file: touch: .*\nExit code: 3\n", 'create_temp_file() - unable to create file');

$commons::verbosity = 2;
is(get_output('commons::clear_temp()'), "Temporary file deleted: /tmp/umi2commons/ttt\n", 'clear temp() - temp file deletion');
ok(!-e '/tmp/umi2commons/ttt', 'clear_temp() - file really deleted');
get_output("commons::create_temp_file('ttt')");
$commons::verbosity = 3;
is(get_output('commons::clear_temp()'), "Temporary file NOT DELETED: /tmp/umi2commons/ttt\n", 'clear temp() - avoiding temp file deletion');
ok(-e '/tmp/umi2commons/ttt', 'clear_temp() - file not deleted in third verbosity mode');
$commons::verbosity = 1;

is(get_output('commons::check_config("LOGS_DIR")'), undef, 'check_config() - real option');
is(get_output('commons::check_config("LOGS_DIR, TIMEOUT")'), "UNKNOWN: Configuration option TIMEOUT is missing!\nExit code: 3\n", 'check_config() - non existent option');
ok(commons::check_config("LOGS_DIR, TIMEOUT", 1) eq 1, "check_config() - non existent option, light version");

ok(commons::is_debug_enabled() eq '', 'is_debug_enabled() - no');
$commons::verbosity = 3;
ok(commons::is_debug_enabled() eq 1, 'is_debug_enabled() - yes');
$commons::verbosity = 1;

$commons::config{'readme_location'} = '/tmp/umi2commons/helpmessage';
`echo -n "Plugin name\n\nHelp message\n.Description" > $commons::config{'readme_location'}`;
is(get_output('commons::show_help();'), "Help message\nExit code: 0\n", 'show_help() - file exists');
$commons::config{'readme_location'} = '/tmp/umi2commons/helpmessage2';
is(get_output('commons::show_help();'), "UNKNOWN: Couldn't load readme file /tmp/umi2commons/helpmessage2!\nExit code: 3\n", 'show_help() - file does not exist');

#$commons::verbosity = 2;
our @conditions = ({'test' => '2 + 2 eq 4', 'output' => 'OK: All right', 'show_debug' => 0 });
is(get_output('commons::check_conditions(\@main::conditions)'), "OK: All right\nExit code: 0\n", 'check_conditions() - one true condition without debug');
@conditions = ({'test' => '2 + 2 eq 4', 'output' => 'OK: All right', 'show_debug' => '`echo Additional debug`' });
is(get_output('commons::check_conditions(\@main::conditions)'), "OK: All right\nAdditional debug\nExit code: 0\n", 'check_conditions() - one true condition with debug');
$commons::verbosity = 2;
@conditions = ( {'test' => '2 + 2 eq 5', 'output' => 'CRITICAL: Wrong', 'show_debug' => 0 }, {'test' => '2 + 2 eq 4', 'output' => 'OK: All right', 'show_debug' => 0 });
is(get_output('commons::check_conditions(\@main::conditions)'), "Checking 2 + 2 eq 5...\nChecking 2 + 2 eq 4...\nListing checker output:\n-----------------------\nOK: All right\n-----------------------\nExit code: 0\n", 'check_conditions() - false and true condition in debug mode');
$commons::verbosity = 1;
@conditions = ({'test' => '2 + 2 eq 5', 'output' => 'CRITICAL: Wrong!', 'show_debug' => 0 });
is(get_output('commons::check_conditions(\@main::conditions)'), undef, 'check_conditions() - only false condition(s)');
@conditions = ({'test' => '2 + 2 eq 4', 'output' => 'CRITICAL: Wrong!', 'show_debug' => 0 });
is(get_output('commons::check_conditions(\@main::conditions)'), "CRITICAL: Wrong!\nExit code: 2\n", 'check_conditions() - non-ok exit status ');

$commons::config{'config_location'} = '/tmp/umi2commons/myGrid/mySite1/myHost1/check_workflow.config';
$commons::config{'UCC_CONFIG'} = '/tmp/umi2commons/myGrid/ucc.config';
$commons::config{'LOGS_DIR'} = '/tmp/umi2commons';
is(get_output('commons::locate_log4j(\'ucc\')'), "UNKNOWN: Unable to find log4j properties file in any place: /tmp/umi2commons/myGrid/mySite1/myHost1/log4j-ucc.properties, /tmp/umi2commons/myGrid/log4j-ucc.properties, /tmp/umi2commons/log4j-ucc.properties\nExit code: 3\n", 'locate_log4j() - missing configuration');
`touch /tmp/umi2commons/log4j-ucc.properties`;
is(commons::locate_log4j('ucc'), '/tmp/umi2commons/log4j-ucc.properties', 'locate_log4j() - logs directory');
`mkdir -p /tmp/umi2commons/myGrid/mySite1/myHost1/`;
`touch /tmp/umi2commons/myGrid/log4j-ucc.properties`;
is(commons::locate_log4j('ucc'), '/tmp/umi2commons/myGrid/log4j-ucc.properties', 'locate_log4j() - client config directory');
`touch /tmp/umi2commons/myGrid/mySite1/myHost1/log4j-ucc.properties`;
is(commons::locate_log4j('ucc'), '/tmp/umi2commons/myGrid/mySite1/myHost1/log4j-ucc.properties', 'locate_log4j() - probe config directory');
$commons::verbosity = 2;
is(get_output('commons::locate_log4j(\'uvosclc\')'), "Listing checker output:\n-----------------------\nUNKNOWN: Unable to find log4j properties file in any place: /tmp/umi2commons/myGrid/mySite1/myHost1/log4j-uvosclc-debug.properties, /tmp/umi2commons/myGrid/log4j-uvosclc-debug.properties, /tmp/umi2commons/log4j-uvosclc-debug.properties\n-----------------------\nExit code: 3\n", 'locate_log4j() - missing debug');
`touch /tmp/umi2commons/myGrid/mySite1/myHost1/log4j-uvosclc-debug.properties`;
is(commons::locate_log4j('uvosclc'), '/tmp/umi2commons/myGrid/mySite1/myHost1/log4j-uvosclc-debug.properties', 'locate_log4j() - debug file');



`rm -rf /tmp/umi2commons`;
